@@ -23,7 +23,6 @@
 #define LINK_COLOR "blue"
 #else
 #define LINK_COLOR "lightblue"
-#define CUSTOM_NOTEBOOK
 #endif
 
 #ifdef ENABLE_BROWSER_INTERFACE
@@ -70,84 +69,6 @@ void on_paypal_button_clicked(GtkButton *button, appdata_t *appdata) {
 }
 #endif
 
-static GtkWidget *notebook_new(void) {
-#ifdef CUSTOM_NOTEBOOK
-  GtkWidget *vbox = gtk_vbox_new(FALSE, 0);
-
-  GtkWidget *notebook =  gtk_notebook_new();
-
-  /* solution for fremantle: we use a row of ordinary buttons instead */
-  /* of regular tabs */
-
-  /* hide the regular tabs */
-  gtk_notebook_set_show_tabs(GTK_NOTEBOOK(notebook), FALSE);
-
-  gtk_box_pack_start_defaults(GTK_BOX(vbox), notebook);
-
-  /* store a reference to the notebook in the vbox */
-  g_object_set_data(G_OBJECT(vbox), "notebook", (gpointer)notebook);
-
-  /* create a hbox for the buttons */
-  GtkWidget *hbox = gtk_hbox_new(TRUE, 0);
-  gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
-  g_object_set_data(G_OBJECT(vbox), "hbox", (gpointer)hbox);
-
-  return vbox;
-#else
-  return gtk_notebook_new();
-#endif
-}
-
-#ifdef CUSTOM_NOTEBOOK
-static void on_notebook_button_clicked(GtkWidget *button, gpointer data) {
-  GtkNotebook *nb = 
-    GTK_NOTEBOOK(g_object_get_data(G_OBJECT(data), "notebook"));
-
-  gint page = (gint)g_object_get_data(G_OBJECT(button), "page");
-  gtk_notebook_set_current_page(nb, page);
-}
-#endif
-
-static void notebook_append_page(GtkWidget *notebook, 
-				 GtkWidget *page, char *label) {
-#ifdef CUSTOM_NOTEBOOK
-  GtkNotebook *nb = 
-    GTK_NOTEBOOK(g_object_get_data(G_OBJECT(notebook), "notebook"));
-
-  gint page_num = gtk_notebook_append_page(nb, page, gtk_label_new(label));
-  GtkWidget *button = NULL;
-
-  /* select button for page 0 by default */
-  if(!page_num) {
-    button = gtk_radio_button_new_with_label(NULL, label);
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
-    g_object_set_data(G_OBJECT(notebook), "group_master", (gpointer)button);
-  } else {
-    GtkWidget *master = g_object_get_data(G_OBJECT(notebook), "group_master");
-    button = gtk_radio_button_new_with_label_from_widget(
-				 GTK_RADIO_BUTTON(master), label);
-  }
-
-  gtk_toggle_button_set_mode(GTK_TOGGLE_BUTTON(button), FALSE);
-  g_object_set_data(G_OBJECT(button), "page", (gpointer)page_num);
-
-  gtk_signal_connect(GTK_OBJECT(button), "clicked",
-	   GTK_SIGNAL_FUNC(on_notebook_button_clicked), notebook);
-
-#if defined(USE_MAEMO) && (MAEMO_VERSION_MAJOR == 5)
-  hildon_gtk_widget_set_theme_size(button, 
-	   (HILDON_SIZE_FINGER_HEIGHT | HILDON_SIZE_AUTO_WIDTH));
-#endif  
-
-  gtk_box_pack_start_defaults(
-     GTK_BOX(g_object_get_data(G_OBJECT(notebook), "hbox")),
-     button);
-
-#else
-  gtk_notebook_append_page(GTK_NOTEBOOK(notebook), page, gtk_label_new(label));
-#endif
-}
-
 GtkWidget *label_big(char *str) {
   GtkWidget *label = gtk_label_new("");
   char *markup = 
@@ -166,27 +87,10 @@ GtkWidget *label_xbig(char *str) {
   return label;
 }
 
-static void
-on_label_realize(GtkWidget *widget, gpointer user_data)  {
-  /* get parent size (which is a container) */
-  gtk_widget_set_size_request(widget, widget->parent->allocation.width, -1);
-}
-
-GtkWidget *label_wrap(char *str) {
-  GtkWidget *label = gtk_label_new(str);
-  gtk_label_set_line_wrap_mode(GTK_LABEL(label), PANGO_WRAP_WORD);
-  gtk_label_set_line_wrap(GTK_LABEL(label), TRUE);
-
-  g_signal_connect(G_OBJECT(label), "realize",
-                   G_CALLBACK(on_label_realize), NULL);
-
-  return label;
-}
-
 GtkWidget *license_page_new(void) {
   char *name = g_strdup(ICONPATH "COPYING");
 
-  GtkWidget *label = label_wrap("");
+  GtkWidget *label = text_wrap("");
 
   /* load license into buffer */
   FILE *file = fopen(name, "r");
@@ -206,16 +110,17 @@ GtkWidget *license_page_new(void) {
     fseek(file, 0l, SEEK_SET);
 
     char *buffer = g_malloc(flen+1);
-    fread(buffer, 1, flen, file);
+    if(fread(buffer, 1, flen, file) != flen) 
+      text_set(label, _("Load error"));
+    else {
+      buffer[flen]=0;
+      text_set(label, buffer);
+    }
+
     fclose(file);
-
-    buffer[flen]=0;
-
-    gtk_label_set_text(GTK_LABEL(label), buffer);
-
     g_free(buffer);
   } else
-    gtk_label_set_text(GTK_LABEL(label), _("Load error"));
+    text_set(label, _("Load error"));
 
 #ifndef USE_PANNABLE_AREA
   GtkWidget *scrolled_window = gtk_scrolled_window_new(NULL, NULL);
@@ -272,7 +177,7 @@ GtkWidget *copyright_page_new(appdata_t *appdata) {
 	      gtk_label_new(_("Copyright 2008-2009")), FALSE, FALSE, 0);
 
   gtk_box_pack_start(GTK_BOX(ivbox), 
-      link_new(appdata, "http://www.harbaum.org/till/maemo#gpxview"),
+      link_new(appdata, "http://gpxview.garage.maemo.org"),
 			      FALSE, FALSE, 0);
 
   gtk_box_pack_start(GTK_BOX(vbox), ivbox, TRUE, FALSE, 0);
@@ -348,7 +253,7 @@ GtkWidget *donate_page_new(appdata_t *appdata) {
   GtkWidget *vbox = gtk_vbox_new(FALSE, 0);
 
   gtk_box_pack_start_defaults(GTK_BOX(vbox), 
-      label_wrap(_("If you like GPXView and want to support its future development "
+      text_wrap(_("If you like GPXView and want to support its future development "
 		   "please consider donating to the developer. You can either "
 		   "donate via paypal to")));
   
@@ -356,7 +261,7 @@ GtkWidget *donate_page_new(appdata_t *appdata) {
 			      link_new(NULL, "till@harbaum.org"));
   
   gtk_box_pack_start_defaults(GTK_BOX(vbox), 
-      label_wrap(_("or you can just click the button below which will open "
+      text_wrap(_("or you can just click the button below which will open "
 		   "the appropriate web page in your browser.")));
 
   GtkWidget *ihbox = gtk_hbox_new(FALSE, 0);
@@ -376,7 +281,7 @@ GtkWidget *bugs_page_new(appdata_t *appdata) {
   GtkWidget *vbox = gtk_vbox_new(FALSE, 0);
 
   gtk_box_pack_start_defaults(GTK_BOX(vbox), 
-      label_wrap(_("Please report bugs or feature requests via the GPXView "
+      text_wrap(_("Please report bugs or feature requests via the GPXView "
 		   "bug tracker. This bug tracker can directly be reached via "
 		   "the following link:")));
 
@@ -384,14 +289,14 @@ GtkWidget *bugs_page_new(appdata_t *appdata) {
        link_new(appdata, "https://garage.maemo.org/tracker/?group_id=973"));
 
   gtk_box_pack_start_defaults(GTK_BOX(vbox), 
-      label_wrap(_("You might also be interested in joining the mailing lists "
+      text_wrap(_("You might also be interested in joining the mailing lists "
 		   "or the forum:")));
 
   gtk_box_pack_start_defaults(GTK_BOX(vbox), 
 	      link_new(appdata, "http://garage.maemo.org/projects/gpxview/"));
 
   gtk_box_pack_start_defaults(GTK_BOX(vbox), 
-      label_wrap(_("Thank you for contributing!")));
+      text_wrap(_("Thank you for contributing!")));
 
   return vbox;
 }  
