@@ -1374,6 +1374,31 @@ gpx_t *gpx_parse_dir(gpx_dialog_t *dialog, char *dirname, char *username) {
 	  fprintf(stderr, "Unable to open %s\n", filename);
 	}
 
+	free(filename);
+
+      } else if(strcasecmp(ext, ".zip") == 0) {
+	char *filename = malloc(strlen(dirname)+strlen(finfo->name)+2);
+
+	strcpy(filename, dirname);
+	if(strlastchr(filename) != '/')
+	  strcat(filename, "/");
+	strcat(filename, finfo->name);
+
+	gpx_t *new_gpx = decompress_zip(dialog, filename, username);
+	if(new_gpx) {
+	  if(!gpx) gpx = new_gpx;
+	  else {
+	    /* append all caches from "new_gpx" to gpx */
+
+	    cache_t **cache = &(gpx->cache);
+	    while(*cache) cache = &(*cache)->next;
+
+	    *cache = new_gpx->cache;
+	    new_gpx->cache = NULL;
+	    gpx_free(new_gpx);
+	  }
+	}
+
 	free(filename);
       }
     }
