@@ -76,6 +76,77 @@
 #define LOG_TYPE_ARCHIVE              15
 #define LOG_TYPE_MAX                  (LOG_TYPE_ARCHIVE)
 
+// gpx 1.0.1 attributes
+#define ATT_UNKNOWN             0
+#define ATT_DOGS                1
+#define ATT_FEE                 2
+#define ATT_RAPPELLING          3
+#define ATT_BOAT                4
+#define ATT_SCUBA               5
+#define ATT_KIDS                6
+#define ATT_ONEHOUR             7
+#define ATT_SCENIC              8
+#define ATT_HIKING              9
+#define ATT_CLIMBING           10
+#define ATT_WADING             11
+#define ATT_SWIMMING           12
+#define ATT_AVAILABLE          13
+#define ATT_NIGHT              14
+#define ATT_WINTER             15
+#define ATT_UNKNOWN0           16  // <-- ???
+#define ATT_POISONOAK          17
+#define ATT_SNAKES             18
+#define ATT_TICKS              19
+#define ATT_MINE               20
+#define ATT_CLIFF              21
+#define ATT_HUNTING            22
+#define ATT_DANGER             23
+#define ATT_WHEELCHAIR         24
+#define ATT_PARKING            25
+#define ATT_PUBLIC             26
+#define ATT_WATER              27
+#define ATT_RESTROOMS          28
+#define ATT_PHONE              29
+#define ATT_PICNIC             30
+#define ATT_CAMPING            31
+#define ATT_BICYCLES           32
+#define ATT_MOTORCYCLES        33
+#define ATT_QUADS              34
+#define ATT_JEEPS              35
+#define ATT_SNOWMOBILES        36
+#define ATT_HORSES             37
+#define ATT_CAMPFIRES          38
+#define ATT_THORN              39
+#define ATT_STEALTH            40
+#define ATT_STROLLER           41
+#define ATT_FIRSTAID           42
+#define ATT_COW                43
+#define ATT_FLASHLIGHT         44
+// august 2010 attributes
+#define ATT_LANDF              45
+#define ATT_UNKNOWN1           46  // <-- ???
+#define ATT_FIELD_PUZZLE       47
+#define ATT_UV                 48
+#define ATT_SNOWSHOES          49
+#define ATT_SKIIS              50
+#define ATT_S_TOOL             51
+#define ATT_NIGHTCACHE         52
+#define ATT_PARKNGRAB          53
+#define ATT_ABANDONEDBUILDING  54
+#define ATT_HIKE_SHORT         55
+#define ATT_HIKE_MED           56
+#define ATT_HIKE_LONG          57
+#define ATT_FUEL               58
+#define ATT_FOOD               59
+#define ATT_MAX                (ATT_FOOD)
+
+typedef struct attribute {
+  char *name;
+  unsigned int id;
+  gboolean inc;
+  struct attribute *next;
+} attribute_t;
+
 typedef struct {
   char *name;
   unsigned int id;
@@ -143,11 +214,12 @@ typedef struct cache {
   gboolean found;      /* determined by log */
   gboolean mine;
 
-  notes_t *notes;      /* user provides data. Doesn't come from gpx file */
-  wpt_t *wpt;          /* pointer to list of waypoints */
-  log_t *log;          /* pointer to list of logs */
-  tb_t *tb;            /* pointer to list of travelbugs */
-  struct cache *next;  /* pointer to next cache in list */
+  notes_t *notes;           /* user provides data. Doesn't come from gpx file */
+  wpt_t *wpt;               /* pointer to list of waypoints */
+  log_t *log;               /* pointer to list of logs */
+  tb_t *tb;                 /* pointer to list of travelbugs */
+  attribute_t *attribute;   /* pointer to list of attributes */
+  struct cache *next;       /* pointer to next cache in list */
 } cache_t;
 
 typedef struct gpx {
