@@ -34,7 +34,8 @@ enum {
   ICON_TB,
   ICON_MISC,
   ICON_POS,
-  ICON_FILE
+  ICON_FILE,
+  ICON_ATT
 };
 
 void icons_init(void);
@@ -43,5 +44,6 @@ void icons_free(void);
 GdkPixbuf *icon_bearing(pos_t from, pos_t to);
 GdkPixbuf *icon_get(int type, int num);
 GtkWidget *icon_get_widget(int type, int num);
+GtkWidget *icon_get_widget_ovl(int type, int num, int ovl);
 
 #endif // ICONS_H
