@@ -123,6 +123,65 @@ void errorf(const char *fmt, ...) {
   free(buf);
 }
 
+/* ------------ app specific gps helper functions, not part -------------- */
+/* ---------------------  of the generic gps.[ch] ------------------------ */
+
+void gps_change_state(appdata_t *appdata) {
+  gps_enable(appdata->gps_state, appdata->use_gps);
+}
+
+pos_t *gps_get_pos(appdata_t *appdata) {
+  static pos_t pos;
+
+  if(appdata->gps.set & FIX_LATLON_SET) {
+    pos.lat = appdata->gps.fix.latitude;
+    pos.lon = appdata->gps.fix.longitude;
+    return &pos;
+  }
+
+  return NULL;
+}
+
+float gps_get_heading(appdata_t *appdata) {
+  if(appdata->gps.set & FIX_TRACK_SET) 
+    return appdata->gps.fix.track;
+
+  return NAN;
+}
+
+gint gps_get_satnum(appdata_t *appdata) {
+  printf("set = %x/%x (snum = %d)\n",  
+	 appdata->gps.set, FIX_SATELLITE_SET, 
+	 appdata->gps.fix.sat_num);
+
+  if(appdata->gps.set & FIX_SATELLITE_SET) 
+    return appdata->gps.fix.sat_num;
+
+  return 0;
+}
+
+gps_sat_t *gps_get_sats(appdata_t *appdata) {
+  if(appdata->gps.set & FIX_SATELLITE_SET) 
+    return appdata->gps.fix.sat_data;
+
+  return NULL;
+}
+
+float gps_get_eph(appdata_t *appdata) {
+  if(appdata->gps.set & FIX_HERR_SET) 
+    return appdata->gps.fix.eph;
+
+  return NAN;
+}
+
+static void 
+main_gps_cb(gps_mask_t set, struct gps_t *fix, void *data) {
+  appdata_t *appdata = (appdata_t*)data;
+
+  appdata->gps.set = set;
+  memcpy(&appdata->gps.fix, fix, sizeof(struct gps_t));
+}
+
 gpx_t *choose_file(appdata_t *appdata, gboolean whole_dir) {
   GtkWidget *dialog;
   gpx_t *gpx = NULL;
@@ -445,6 +504,27 @@ static gboolean on_cachelist_focus_out(GtkWidget *widget, GdkEventFocus *event,
   return FALSE;
 }  
 
+gboolean on_main_focus_change(GtkWidget *widget, GdkEventFocus *event,
+				gpointer user_data) {
+  appdata_t *appdata = (appdata_t*)user_data;
+  g_assert(appdata->gps_state);
+
+  printf("main/cachelist focus-%s event\n", event->in?"in":"out");
+
+  /* disconnect from gps if map looses focus */
+  /* this is to save energy if maep runs in background */
+  
+  if(event->in) {
+    /* request all GPS information required for map display */
+    gps_register_callback(appdata->gps_state, 
+	  LATLON_CHANGED | TRACK_CHANGED | HERR_CHANGED | SATELLITE_CHANGED,
+          main_gps_cb, appdata);
+  } else
+    gps_unregister_callback(appdata->gps_state, main_gps_cb);
+
+  return FALSE;
+}
+
 static GtkWidget *cachelist_create(appdata_t *appdata, gpx_t *gpx,
 				   cache_t *sel_cache) {
   GtkCellRenderer *renderer;
@@ -711,6 +791,13 @@ void cachelist_dialog(appdata_t *appdata, gpx_t *gpx) {
   hildon_window_set_app_menu(HILDON_WINDOW(window), 
 			     menu_create(appdata, MENU_CACHELIST));
 
+  /* make sure window can control gps */
+  g_signal_connect(G_OBJECT(window), "focus-in-event", 
+		   G_CALLBACK(on_main_focus_change), appdata);
+  
+  g_signal_connect(G_OBJECT(window), "focus-out-event", 
+		   G_CALLBACK(on_main_focus_change), appdata);
+
   g_signal_connect(G_OBJECT(window), "destroy", 
 		   G_CALLBACK(on_cachelist_destroy), appdata);
 
@@ -2070,7 +2157,9 @@ void cleanup(appdata_t *appdata) {
 
   gnome_vfs_shutdown();
   icons_free();
-  gps_release(appdata);
+
+  gps_release(appdata->gps_state);
+  appdata->gps_state = NULL;
 
   if(appdata->search_results) {
     printf("freeing pending search\n");
@@ -2507,7 +2596,20 @@ int main(int argc, char *argv[]) {
   appdata.gconf_client = gconf_client_get_default();
   gconf_load_state(&appdata);
 
-  gps_init(&appdata);
+  appdata.gps_state = gps_init();
+  gps_change_state(&appdata);
+
+  gps_register_callback(appdata.gps_state, 
+	  LATLON_CHANGED | TRACK_CHANGED | HERR_CHANGED | SATELLITE_CHANGED,
+          main_gps_cb, &appdata);
+
+  /* make sure window can control gps */
+  g_signal_connect(G_OBJECT(appdata.window), "focus-in-event", 
+		   G_CALLBACK(on_main_focus_change), &appdata);
+  
+  g_signal_connect(G_OBJECT(appdata.window), "focus-out-event", 
+		   G_CALLBACK(on_main_focus_change), &appdata);
+
 
   appdata.cur_view = gpxlist_create_view_and_model(&appdata, NULL);
 #ifndef USE_STACKABLE_WINDOW
