@@ -1058,7 +1058,8 @@ void map(appdata_t *appdata) {
 
   context->widget = g_object_new(OSM_TYPE_GPS_MAP,
 		 "map-source",               source,
-                 "tile-cache",               path,
+		 "tile-cache",               OSM_GPS_MAP_CACHE_FRIENDLY,
+		 "tile-cache-base",          path,
 		 "auto-center",              FALSE,
 		 "record-trip-history",      FALSE, 
 		 "show-trip-history",        FALSE, 
